==> mesian-v0.1.2.tar.bz2: mesian-v0.1.2/www-data/lib/Basic_message.php <==
<?
// Wriiten by Spike^ekipS <spike@spikeekips.net>
include_once $global["root"] . "/module/message/function/etc.php";
include_once $global["root"] . "/module/message/function/do.php";
include_once $global["root"] . "/module/message/function/parseContent.php";

class Basic_message {

	var $Template;

	var $SQL_GET_MAIL_ITEM =
		"select SQL_CACHE
			header, headerSimple, textBody, htmlBody, payload,
			headerPayload, cid, headerCid, entireMessage, isPayload, isCid,
			flag, date from mail_%s where no = '%s'";
	var $SQL_GET_ENTIREMESSAGE =
			"select SQL_CACHE message from mail_entireMessage_%s where no = '%s'";
	var $SQL_INSERT_ENTIREMESSAGE =
			"insert into mail_entireMessage_%s (message) values('%s')";
	var $SQL_GET_MAIL_INFO =
		"select SQL_CACHE headerSimple, date, flag, type, notified
			from mail_%s where no = '%s'";
	var $SQL_GET_REMOVE_ITEM =
			"select SQL_CACHE cid, payload, entireMessage from mail_%s where no = '%s'";
	var $SQL_REMOVE_MAIL = "delete from mail_%s where no = '%s'";
	var $SQL_REMOVE_ENTIREMESSAGE =
			"delete from mail_entireMessage_%s where no = '%s'";
	var $SQL_SEARCH_MAIL =
			"select SQL_CACHE no from mail_%s where no = '%s' and (%s)";
	var $SQL_GET_SIZE_ITEM =
		"select SQL_CACHE sum(t2.size) as size
			from mail_%s as t1, mail_entireMessage_%s as t2
			where %s and t1.entireMessage = t2.no";
	//-------------------------------------------------- function
	function Basic_message () {
		$this->Template = new Template;
	}

	function copy ($no) {

		$DB = new MySQLdb;

		//------------ fetch from original message.
		$c = $DB->fetch_one(sprintf($this->SQL_GET_MAIL_ITEM, $_SESSION["config_id"], $no));
		//------------

		if (! $c["header"]) {
			$retval = false;
		} else {
			//------------ get entiremessage from mail_entireMessage_%s.
			$d = $DB->fetch_one(sprintf($this->SQL_GET_ENTIREMESSAGE,
				$_SESSION["config_id"], $c["entireMessage"]));

			//------------ insert same data into mail_%s.
			$DB->query(sprintf($this->SQL_INSERT_ENTIREMESSAGE,
					$_SESSION["config_id"], addslashes($d["message"])));

			$retval = $DB->retval;

			if ($retval) {
				//------------ insert same data into mail_%s.
				$DB->query(sprintf($this->SQL_INSERT_ITEMS_TO_MODULE,
					$_SESSION["config_id"],
						addslashes($c["header"]), addslashes($c["headerSimple"]),
						addslashes($c["textBody"]), addslashes($c["htmlBody"]),
						addslashes($c["payload"]), addslashes($c["headerPayload"]),
						addslashes($c["cid"]), addslashes($c["headerCid"]),
						$c["isPayload"], $c["isCid"], $c["flag"], $c["date"]));

				$retval = $DB->retval;
			}
		}

		if ($retval) $retval = $DB->get_last_insert_id();

		return $retval;
	}

	function info ($no, $type=false) {
		global $global, $string;

		$DB = new MySQLdb;

		$o = $DB->fetch_one(sprintf($this->SQL_GET_MAIL_INFO, $_SESSION["config_id"], $no));

		if (! is_array($o)) {
			$b = false;
		} else {
			$a = parseHeader($o["headerSimple"]);

			if (trim($a["subject"]) == "") $a["subject"] = "No Subject";
			$b["createdTime"] = $o["date"];
			$b["flag"] = $o["flag"];
			$b["type"] = $o["type"];

			if ($o["notified"] == "1") {
				$b["title"] =
					sprintf("%s (%s)", htmlspecialchars($a["subject"]), $string["message84"]);
			} else {
				$b["title"] = htmlspecialchars($a["subject"]);
			}

			$Address = new Address();
			// inbox or sent?
			if ($_SESSION["user_directory"] == $global["directory"]["sent"]) { // sent.
				$b["author"] = $Address->return_split($a["to"]);
			} else {
				$b["author"] = $Address->return_split($a["from"]);
			}
		}

		$retval = $b;

		return $retval;
	}

	function remove ($no) {
		global $global;

		$DB = new MySQLdb;

		$o = $DB->fetch_one(sprintf($this->SQL_GET_REMOVE_ITEM,
				$_SESSION["config_id"], $no));

		$DB->query(sprintf($this->SQL_REMOVE_MAIL, $_SESSION["config_id"], $no));
		$retval = $DB->retval;

		if ($retval) {
			$DB->query(sprintf($this->SQL_REMOVE_ENTIREMESSAGE,
				$_SESSION["config_id"], $o["entireMessage"]));
			$retval = $DB->retval;
		}

		# remove cid & payload file in data directory.
		if ($retval) {
			if ($o["cid"]) {
				$a = explode(";", $o["cid"]);

				while (list($i, $j) = each($a)) {
					$filename = sprintf("%s/cid/%s/%s",
						$global["data"], $_SESSION["config_id"], $j);
					unlink($filename);
				}
			}

			if ($o["payload"]) {
				$a = explode(";", $o["payload"]);

				while (list($i, $j) = each($a)) {
					$filename = sprintf("%s/payload/%s/%s",
						$global["data"], $_SESSION["config_id"], $j);
					unlink($filename);
				}
			}
		}

		return $retval;
	}

	function search ($str, $data, $case="",$all="0") {
		global $global, $string;

		$DB = new MySQLdb;
		$Directory = new myDirectory;

		// $all is just list all.
		if ($all != "1") {
			$a = preg_split("/ \t*/", $str);

			$col = array("headerSimple", "textBody", "htmlBody", "entireMessage");

			if ($case) {
				while (list($i, $j) = each($col)) {
					$c[] = sprintf("%s regexp binary '%s'", $j, addslashes($str));
				}
			} else {
				$b = "%" . addslashes(implode("%", $a)) . "%";
				while (list($i, $j) = each($col)) {
					$c[] = sprintf("%s like '%s'", $j, $b);
				}
			}

			$d = implode(" or ", $c);
		}

		while (list($i, $j) = each($data)) {

			if ($all != "1") {
				$o = $DB->fetch_one(sprintf($this->SQL_SEARCH_MAIL,
						$_SESSION["config_id"], $i, $d));

				if (! $o["no"]) continue;
			}

			$b = $this->info($i);

			//--------------------------------------------------
			// data handling
			$c["createdTime"] = print_time($b["createdTime"], "simple");

			if ($b["author"]["short"]) {
				$c["author"] = $b["author"]["short"];
			} else {
				$c["author"] = $b["author"]["full"];
			}

			$c["title"] = sprintf("<a class=\"mesian\"
				href=\"%s/mail?no=%s&mode=view\">%s</a>",
				$_SESSION["user_www_url"], $j["no"], htmlspecialchars($b["title"]));

			$c["icon"] = sprintf("<img class=\"mesian\" src=\"%s/module/message/image/content_type-25.png\">",
				$_SESSION["user_www_url"]);

			$Directory->no = $j["directory_num"];

			$c["directory"] =
				sprintf("<a class=\"mesian\" href=\"%s/mail?no=%s\">%s</a>",
					$_SESSION["user_www_url"], $j["directory_num"],
					$Directory->get_name());

			$main["content"] .=
				$this->Template->generate("/module/item/template/search_result_line", $c);
		}

		$main["module_name"] = "Mail Message";

		$retval =
			$this->Template->generate("/module/item/template/search_result_module", $main);

		return $retval;
	}

	function size ($no) {

		$DB = new MySQLdb;

		if (! is_array($no)) {
			$a = sprintf("t1.no = '%s'", $no);
		} else {
			while (list($i, $j) = each($no)) {
				$b[] = sprintf("t1.no = '%s'", $j);
			}
			$a = sprintf("(%s)", implode(" or ", $b));
		}

		$o = $DB->fetch_one(sprintf($this->SQL_GET_SIZE_ITEM,
				$_SESSION["config_id"],$_SESSION["config_id"], $a));

		$retval = $o["size"];

		return $retval;
	}
}

/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>

==> mesian-v0.2-rc2.tar.bz2: mesian-v0.2-rc2/www-data/lib/Basic_message.php <==
<?
// Wriiten by Spike^ekipS <spike@spikeekips.net>
include_once $global["root"] . "/module/message/function/etc.php";
include_once $global["root"] . "/module/message/function/do.php";
include_once $global["root"] . "/module/message/function/parseContent.php";

class Basic_message {

	var $Template;

	var $SQL_GET_MAIL_ITEM =
		"select SQL_CACHE
			header, headerSimple, textBody, htmlBody, payload,
			headerPayload, cid, headerCid, entireMessage, isPayload, isCid,
			flag, date from mail_%s where no = '%s'";
	var $SQL_GET_ENTIREMESSAGE =
			"select SQL_CACHE message from mail_entireMessage_%s where no = '%s'";
	var $SQL_INSERT_ENTIREMESSAGE =
			"insert into mail_entireMessage_%s (message) values('%s')";
	var $SQL_GET_MAIL_INFO =
		"select SQL_CACHE headerSimple, date, flag, type, notified
			from mail_%s where no = '%s'";
	var $SQL_GET_REMOVE_ITEM =
			"select SQL_CACHE cid, payload, entireMessage from mail_%s where no = '%s'";
	var $SQL_REMOVE_MAIL = "delete from mail_%s where no = '%s'";
	var $SQL_REMOVE_ENTIREMESSAGE =
			"delete from mail_entireMessage_%s where no = '%s'";
	var $SQL_SEARCH_MAIL =
			"select SQL_CACHE no from mail_%s where no = '%s' and (%s)";
	var $SQL_GET_SIZE_ITEM =
		"select SQL_CACHE sum(t2.size) as size
			from mail_%s as t1, mail_entireMessage_%s as t2
			where %s and t1.entireMessage = t2.no";
	//-------------------------------------------------- function
	function Basic_message () {
		$this->Template = new Template;
	}

	function copy ($no) {

		$DB = new MySQLdb;

		//------------ fetch from original message.
		$c = $DB->fetch_one(sprintf($this->SQL_GET_MAIL_ITEM, $_SESSION["config_id"], $no));
		//------------

		if (! $c["header"]) {
			$retval = false;
		} else {
			//------------ get entiremessage from mail_entireMessage_%s.
			$d = $DB->fetch_one(sprintf($this->SQL_GET_ENTIREMESSAGE,
				$_SESSION["config_id"], $c["entireMessage"]));

			//------------ insert same data into mail_%s.
			$DB->query(sprintf($this->SQL_INSERT_ENTIREMESSAGE,
					$_SESSION["config_id"], addslashes($d["message"])));

			$retval = $DB->retval;

			if ($retval) {
				//------------ insert same data into mail_%s.
				$DB->query(sprintf($this->SQL_INSERT_ITEMS_TO_MODULE,
					$_SESSION["config_id"],
						addslashes($c["header"]), addslashes($c["headerSimple"]),
						addslashes($c["textBody"]), addslashes($c["htmlBody"]),
						addslashes($c["payload"]), addslashes($c["headerPayload"]),
						addslashes($c["cid"]), addslashes($c["headerCid"]),
						$c["isPayload"], $c["isCid"], $c["flag"], $c["date"]));

				$retval = $DB->retval;
			}
		}

		if ($retval) $retval = $DB->get_last_insert_id();

		return $retval;
	}

	function info ($no, $type=false) {
		global $global, $string;

		$DB = new MySQLdb;

		$o = $DB->fetch_one(sprintf($this->SQL_GET_MAIL_INFO, $_SESSION["config_id"], $no));

		if (! is_array($o)) {
			$b = false;
		} else {
			$a = parseHeader($o["headerSimple"]);

			if (trim($a["subject"]) == "") $a["subject"] = "No Subject";
			$b["createdTime"] = $o["date"];
			$b["flag"] = $o["flag"];
			$b["type"] = $o["type"];

			if ($o["notified"] == "1") {
				$b["title"] =
					sprintf("%s (%s)", htmlspecialchars($a["subject"]), $string["message84"]);
			} else {
				$b["title"] = htmlspecialchars($a["subject"]);
			}

			$Address = new Address();
			// inbox or sent?
			if ($_SESSION["user_directory"] == $global["directory"]["sent"]) { // sent.
				$b["author"] = $Address->return_split($a["to"]);
			} else {
				$b["author"] = $Address->return_split($a["from"]);
			}
		}

		$retval = $b;

		return $retval;
	}

	function remove ($no) {
		global $global;

		$DB = new MySQLdb;

		$o = $DB->fetch_one(sprintf($this->SQL_GET_REMOVE_ITEM,
				$_SESSION["config_id"], $no));

		$DB->query(sprintf($this->SQL_REMOVE_MAIL, $_SESSION["config_id"], $no));
		$retval = $DB->retval;

		if ($retval) {
			$DB->query(sprintf($this->SQL_REMOVE_ENTIREMESSAGE,
				$_SESSION["config_id"], $o["entireMessage"]));
			$retval = $DB->retval;
		}

		# remove cid & payload file in data directory.
		if ($retval) {
			if ($o["cid"]) {
				$a = explode(";", $o["cid"]);

				while (list($i, $j) = each($a)) {
					$filename = sprintf("%s/cid/%s/%s",
						$global["data"], $_SESSION["config_id"], $j);
					unlink($filename);
				}
			}

			if ($o["payload"]) {
				$a = explode(";", $o["payload"]);

				while (list($i, $j) = each($a)) {
					$filename = sprintf("%s/payload/%s/%s",
						$global["data"], $_SESSION["config_id"], $j);
					unlink($filename);
				}
			}
		}

		return $retval;
	}

	function search ($str, $data, $case="",$all="0") {
		global $global, $string;

		$DB = new MySQLdb;
		$Directory = new myDirectory;

		// $all is just list all.
		if ($all != "1") {
			$a = preg_split("/ \t*/", $str);

			$col = array("headerSimple", "textBody", "htmlBody", "entireMessage");

			if ($case) {
				while (list($i, $j) = each($col)) {
					$c[] = sprintf("%s regexp binary '%s'", $j, addslashes($str));
				}
			} else {
				$b = "%" . addslashes(implode("%", $a)) . "%";
				while (list($i, $j) = each($col)) {
					$c[] = sprintf("%s like '%s'", $j, $b);
				}
			}

			$d = implode(" or ", $c);
		}

		while (list($i, $j) = each($data)) {

			if ($all != "1") {
				$o = $DB->fetch_one(sprintf($this->SQL_SEARCH_MAIL,
						$_SESSION["config_id"], $i, $d));

				if (! $o["no"]) continue;
			}

			$b = $this->info($i);

			//--------------------------------------------------
			// data handling
			$c["createdTime"] = print_time($b["createdTime"], "simple");

			if ($b["author"]["short"]) {
				$c["author"] = $b["author"]["short"];
			} else {
				$c["author"] = $b["author"]["full"];
			}

			$c["title"] = sprintf("<a class=\"mesian\"
				href=\"%s/mail?no=%s&mode=view\">%s</a>",
				$_SESSION["user_www_url"], $j["no"], $b["title"]);

			$c["icon"] = sprintf("<img class=\"mesian\"
				src=\"%s/module/message/image/content_type-25.png\">",
				$_SESSION["user_www_url"]);

			$Directory->no = $j["directory_num"];

			$c["directory"] =
				sprintf("<a class=\"mesian\" href=\"%s/mail?no=%s\">%s</a>",
					$_SESSION["user_www_url"], $j["directory_num"],
					$Directory->get_name());

			$main["content"] .=
				$this->Template->generate("/module/item/template/search_result_line", $c);
		}

		$main["module_name"] = "Mail Message";

		$retval =
			$this->Template->generate("/module/item/template/search_result_module", $main);

		return $retval;
	}

	function size ($no) {

		$DB = new MySQLdb;

		if (! is_array($no)) {
			$a = sprintf("t1.no = '%s'", $no);
		} else {
			while (list($i, $j) = each($no)) {
				$b[] = sprintf("t1.no = '%s'", $j);
			}
			$a = sprintf("(%s)", implode(" or ", $b));
		}

		$o = $DB->fetch_one(sprintf($this->SQL_GET_SIZE_ITEM,
				$_SESSION["config_id"],$_SESSION["config_id"], $a));

		$retval = $o["size"];

		return $retval;
	}
}

/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>
